@@ -288,6 +288,7 @@ enum OER_ADVERT_TYPES {
 #define READ_BUFFER_LENGTH IRCD_BUFFER_LENGTH
 /* we leave 80 bytes for header strings */
 #define WRITE_BUFFER_HEADER_LENGTH 80
+#define MICROSTRINGLEN 16
 #define TINYSTRINGLEN 32
 #define MIDSTRINGLEN 64
 #define STRINGLEN 128
@@ -303,7 +304,7 @@ enum OER_ADVERT_TYPES {
 #define OER_HELP "For a complete command reference go to http://oer.equnet.org/help.html"
 #define DEFAULT_NICKBK_MESSAGE "prohibited nick"
 #define OER_REALNAME "http://oer.equnet.org/help.html"
-#define OER_COPYRIGHT1 "oer version 1.0-31, Copyright (C) 2000 EQU <equ@equnet.org>"
+#define OER_COPYRIGHT1 "oer version 1.0-32, Copyright (C) 2000 EQU <equ@equnet.org>"
 #define OER_COPYRIGHT2 "oer comes with ABSOLUTELY NO WARRANTY; for details see the\n\
 GNU General Public License (COPYING) provided with this distribution.\n\
 This is free software, and you are welcome to redistribute it under\n\
@@ -508,7 +509,7 @@ struct state {
 	char preferredserver[HOSTLEN + 1];
 	char realname[STRINGLEN + 1];
 	char flags[FLAGLEN + 1];
-	char prefix;
+	char prefix[MICROSTRINGLEN + 1];
 	int customuser;
 	int vhost;
 	int use_alt_nick;
