@@ -27,7 +27,6 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "oer.h"
 #include "ds.h"
 #include "misc.h"
-#include "list.h"
 #include "reg.h"
 #include "network.h"
 
@@ -555,7 +554,7 @@ void parseirc(char *serveroutput)
                            bogus/lagged server/service messages */
                         return;
                 }
-		oer_debug(OER_DEBUG_INFO, "parseirc(KICK)->%s!%s off %s by %s!%s\n", target, cu->host, channel, nick, host);
+		oer_debug(OER_DEBUG_INFO, "parseirc(KICK)->%s!%s off %s by %s!%s\n", target, (cu->host == NULL) ? "(null)" : cu->host, channel, nick, host);
 		addnewpart(channel, mystate->now, target, cu->host);
 		if(!userleft(channel, target, cu->host)) {
 			oer_debug(OER_DEBUG_INFO, "parseirc(KICK)->userleft() returned NULL\n");
@@ -720,6 +719,7 @@ void parseirc(char *serveroutput)
 void parsemsg(char *nick, char *host, char *target, char *message)
 {
 	int ctcp;
+	int ppos;
 
 	oer_debug(OER_DEBUG_INFO, "parsemsg->%s!%s target: %s message: %s\n", nick, host, target, message);
 	ctcp = 0;
@@ -786,10 +786,16 @@ void parsemsg(char *nick, char *host, char *target, char *message)
 		/* we don't log ctcp (not even ACTIONS) */
 		return;
 	}
-	if(message[0] == mystate->prefix) {
-		/* here is when we parse all commands */
-		parsecommand(target, nick, host, message + 1);
-	}
+	if(!strncasecmp(message, mystate->prefix, strlen(mystate->prefix))) {
+                ppos = strlen(mystate->prefix);
+                if(isspace((int)message[ppos])) {
+                        while(isspace((int)message[ppos])) {
+                                ppos++;
+                        }
+                }
+                /* here is when we parse all commands */
+                parsecommand(target, nick, host, message + ppos);
+        }
 	if(hasuserflags(target, host, "x")) {
 		/* user's messages won't be saved */
 		oer_debug(OER_DEBUG_INFO, "parsemsg->messages from %s to %s won't be saved\n", nick, target);
@@ -1025,8 +1031,8 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 			if(u == NULL) {
 				return;
 			}
-			snprintf(outstring, WRITE_BUFFER_LENGTH, "KICK %s %s :random kick by %s\n", channel, u->nick, nick);
-			addnewtimed(mystate->now, OER_TIMED_IRC_COMMAND, OER_TIMED_IRC_COMMAND_DUMMY, outstring, NULL, NULL, NULL);
+			snprintf(outstring, WRITE_BUFFER_LENGTH, "random ban kick by %s\n", nick);
+			kickuser(channel, u->nick, outstring);
 		}
 		return;
 	case OER_WHICHCOMMAND_RANDOM_BANKICK:
@@ -1047,7 +1053,8 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 				return;
 			}
 			snprintf(outstring, WRITE_BUFFER_LENGTH, "random ban kick by %s\n", nick);
-			bankickuser(channel, u->nick, outstring);
+			banuser(channel, u->nick);
+			kickuser(channel, u->nick, outstring);
 		}
 		return;
 	case OER_WHICHCOMMAND_SYNC:
@@ -1249,8 +1256,8 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		if((ppos = parse(restptr, ppos, " ", p1, STRINGLEN, 0)) < 0) {
 			return;
 		}
-		/* bankick user, with or without given reason */
-		bankickuser(channel, p1, (strlen(restptr + ppos) > 0) ? restptr + ppos : NULL);
+		banuser(channel, p1);
+		kickuser(channel, p1, (strlen(restptr + ppos) > 0) ? restptr + ppos : NULL);
 		return;
 	case OER_WHICHCOMMAND_KICK:
 		oer_debug(OER_DEBUG_INFO, "parsecommand->KICK\n");
@@ -1267,7 +1274,6 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		if((ppos = parse(restptr, ppos, " ", p1, STRINGLEN, 0)) < 0) {
 			return;
 		}
-		/* kick user, with or without given reason */
 		kickuser(channel, p1, (strlen(restptr + ppos) > 0) ? restptr + ppos : NULL);
 		return;
 	case OER_WHICHCOMMAND_INVITE:
